@@ -247,7 +247,9 @@ def train(sys_args):
         if len(set(ts_trainer.training_ranks).difference(set(taxa_evo_dists))) > 0 or len(clade_ex_pqueries) == 0:
             clade_ex_pqueries = placement_trainer.gen_cladex_data(train_seqs.file, ts_trainer.executables,
                                                                   ts_trainer.ref_pkg, ts_trainer.seq_lineage_map,
-                                                                  ts_trainer.stage_output_dir, args.num_threads)
+                                                                  ts_trainer.stage_output_dir,
+                                                                  max_examples=args.max_examples,
+                                                                  num_threads=args.num_threads)
             jdump(value=clade_ex_pqueries, filename=os.path.join(ts_trainer.clade_ex_pquery_pkl))
 
         # Write the tab-delimited file with metadata included for each placement
@@ -483,7 +485,7 @@ def create(sys_args):
     fasta.write_new_fasta(fasta_dict=ref_seqs.fasta_dict, fasta_name=ref_seqs.file, headers=filtered_headers)
 
     ##
-    # Optionally cluster the input sequences using USEARCH at the specified identity
+    # Optionally cluster the input sequences using VSEARCH at the specified identity
     ##
     if ts_create.stage_status("cluster"):
         ref_seqs.change_dict_keys("num")
@@ -493,7 +495,7 @@ def create(sys_args):
                               fasta_name=ts_create.cluster_input,
                               headers=list(fasta_records.keys()))
         if args.cluster:
-            wrapper.cluster_sequences(ts_create.executables["usearch"], ts_create.cluster_input,
+            wrapper.cluster_sequences(ts_create.executables["vsearch"], ts_create.cluster_input,
                                       ts_create.uclust_prefix, ts_create.ref_pkg.pid)
             ts_create.uc = ts_create.uclust_prefix + ".uc"
         # Read the uc file if present
@@ -845,7 +847,7 @@ def update(sys_args):
         # not all clustering tools + versions keep whole header - spaces are replaced with underscores
         fasta.write_new_fasta(fasta_dict=combined_fasta.fasta_dict,
                               fasta_name=ts_updater.cluster_input)
-        wrapper.cluster_sequences(ts_updater.executables["usearch"], ts_updater.cluster_input,
+        wrapper.cluster_sequences(ts_updater.executables["vsearch"], ts_updater.cluster_input,
                                   ts_updater.uclust_prefix, ts_updater.prop_sim)
         ts_updater.uc = ts_updater.uclust_prefix + ".uc"
 
@@ -1070,7 +1072,7 @@ def layer(sys_args):
         # Determine the marker being annotated
         data_type, refpkg_prefix = "", ""
         for refpkg_name in refpkg_dict:  # type: str
-            annot_marker_re = re.compile(r"^{0}_(\w+).txt$".format(refpkg_name))
+            annot_marker_re = re.compile(r"^{0}_(\w+)_colours_style.txt$".format(refpkg_name))
             if annot_marker_re.match(os.path.basename(annot_f)):
                 data_type = annot_marker_re.match(os.path.basename(annot_f)).group(1)
                 refpkg_prefix = refpkg_name
