@@ -5,44 +5,16 @@ import re
 import glob
 import os
 import logging
-from .classy import ItolJplace, TreeProtein
 from json import load, loads, dumps
-from .utilities import clean_lineage_string
 
-
-def children_lineage(leaves_taxa_map: dict, pquery: str, node_map: dict):
-    """
-    From the jplace placement field ()
-    :param leaves_taxa_map: Dictionary mapping tree leaf nodes to taxonomic lineages
-    :param pquery:
-    :param node_map:
-    :return:
-    """
-    children = list()
-    placement = loads(pquery, encoding="utf-8")
-    loci = placement['p']
-    for locus in loci:
-        jplace_node = locus[0]
-        tree_leaves = node_map[jplace_node]
-        for tree_leaf in tree_leaves:
-            # ref_leaf is a TreeLeafReference object
-            try:
-                ref_lineage = leaves_taxa_map[tree_leaf]
-            except KeyError:
-                logging.error("Unable to find '" + tree_leaf + "' in leaf-lineage map.\n")
-                sys.exit(3)
-            if ref_lineage:
-                children.append(clean_lineage_string(ref_lineage))
-            else:
-                logging.warning("No lineage information available for " + tree_leaf + ".\n")
-
-    return children
+from treesapp.phylo_seq import JPlace, PQuery
 
 
 def pquery_likelihood_weight_ratio(pquery, position):
     """
     Determines the likelihood weight ratio (LWR) for a single placement. There may be multiple placements
     (or 'pquery's) in a single .jplace file. Therefore, this function is usually looped over.
+
     :param pquery:
     :param position: The position of "like_weight_ration" in the pquery fields
     :return: The float(LWR) of a single placement
@@ -59,13 +31,14 @@ def pquery_likelihood_weight_ratio(pquery, position):
     return lwr
 
 
-def jplace_parser(filename):
+def jplace_parser(filename: str) -> JPlace:
     """
     Parses the jplace file using the load function from the JSON library
+
     :param filename: jplace file output by RAxML
-    :return: ItolJplace object
+    :return: JPlace object
     """
-    itol_datum = ItolJplace()
+    itol_datum = JPlace()
     with open(filename) as jplace:
         jplace_dat = load(jplace, encoding="utf-8")
         itol_datum.tree = jplace_dat["tree"]
@@ -84,20 +57,36 @@ def jplace_parser(filename):
     return itol_datum
 
 
-def demultiplex_pqueries(jplace_data):
+def demultiplex_pqueries(jplace_data: JPlace, pquery_map=None) -> list:
+    """
+    Demultiplexes each placed query sequence (PQuery) into its own PQuery instance,
+    copying over all JPlace information and the set of possible placements.
+
+    :param jplace_data: A JPlace instance
+    :param pquery_map: A dictionary mapping placed query sequence names to their respective PQuery instances
+    :return: List of PQuery instances
+    """
     tree_placement_queries = list()
     for pquery in jplace_data.placements:
-        pquery_obj = TreeProtein()
-        pquery_obj.transfer(jplace_data)
+        pquery_obj = PQuery()
+        # Copy the essential information to the PQuery instance
         pquery_obj.placements = [pquery]
         pquery_obj.name_placed_sequence()
+
+        if pquery_map:
+            pquery_obj = pquery_map[pquery_obj.place_name]
+            pquery_obj.placements = [pquery]
+            # Placed sequence has already been named
+
+        pquery_obj.transfer_metadata(jplace_data)
         pquery_obj.correct_decoding()
+
         tree_placement_queries.append(pquery_obj)
 
     return tree_placement_queries
 
 
-def filter_jplace_data(jplace_data: ItolJplace, tree_saps: list):
+def filter_jplace_data(jplace_data: JPlace, tree_saps: list):
     """
     Removes unclassified pqueries from the placements element in jplace_data
 
@@ -108,7 +97,7 @@ def filter_jplace_data(jplace_data: ItolJplace, tree_saps: list):
     jplace_data.correct_decoding()
     jplace_data.filter_max_weight_placement()
     new_placement_collection = list()
-    sapling_map = {sapling.contig_name: sapling for sapling in tree_saps}
+    sapling_map = {sapling.place_name: sapling for sapling in tree_saps}
 
     for d_place in jplace_data.placements:
         dict_strings = list()
@@ -135,12 +124,12 @@ def filter_jplace_data(jplace_data: ItolJplace, tree_saps: list):
     return jplace_data
 
 
-def write_jplace(itol_datum: ItolJplace, jplace_file: str):
+def write_jplace(itol_datum: JPlace, jplace_file: str):
     """
     A hacky function for writing jplace files with concatenated placements
      which are also compatible with iTOL's jplace parser
 
-    :param itol_datum: A ItolJplace class object
+    :param itol_datum: A JPlace class object
     :param jplace_file: A JPlace file path to write to
     :return:
     """
@@ -184,48 +173,44 @@ def write_jplace(itol_datum: ItolJplace, jplace_file: str):
     return
 
 
-def organize_jplace_files(jplace_files):
+def organize_jplace_files(jplace_files: list) -> dict:
     """
-    Given a list of jplace files, a dictionary indexed by the prefix will be returned.
-        Subtle and probably inconsequential checks are also made.
+    Given a list of jplace files, construct a dictionary of jplace files indexed by their refpkg prefix (denominator).
+
     :param jplace_files: list object containing full paths to jplace files generated by RAxML
-    :return: dictionary indexed by the prefix (marker code)
+    :return: Dictionary indexed by the refpkg prefix (marker code)
     """
-    jplace_marker_re = re.compile(r".*portableTree.([A-Z][0-9]{4})(.*).jplace$")
-    jplace_phylocog_re = re.compile(r".*portableTree.([a-z])(.*).jplace$")
+    jplace_marker_re = re.compile(r".*epa_result.(.*)_hmm_purified_.*.jplace$")
     jplace_collection = dict()
     for filename in jplace_files:
-        file_name_info = None
-        for jplace_pattern in [jplace_marker_re, jplace_phylocog_re]:
-            if jplace_pattern.match(filename):
-                file_name_info = jplace_pattern.match(filename)
-                break
-        if not file_name_info:
-            sys.stderr.write("\nRegex parsing marker information from jplace files was unsuccessful!\n")
-            raise AssertionError("The offending file name: " + filename)
+        file_name_info = jplace_marker_re.match(filename)
+        try:
+            refpkg_name = file_name_info.group(1)
+        except AttributeError:
+            logging.error("Regex parsing marker information from jplace files was unsuccessful!\n"
+                          "The offending file name: " + filename + "\n")
+            sys.exit(7)
 
-        denominator = file_name_info.group(1)
-        description = file_name_info.group(2)
-
-        if denominator not in jplace_collection:
-            jplace_collection[denominator] = list()
-        jplace_collection[denominator].append(filename)
+        if refpkg_name not in jplace_collection:
+            jplace_collection[refpkg_name] = list()
+        jplace_collection[refpkg_name].append(filename)
     return jplace_collection
 
 
-def sub_indices_for_seq_names_jplace(jplace_dir, numeric_contig_index, marker_build_dict):
+def sub_indices_for_seq_names_jplace(jplace_dir, numeric_contig_index, refpkg_dict):
     """
     Ugly script for running re.sub on a set of jplace files
+
     :param jplace_dir:
     :param numeric_contig_index:
-    :param marker_build_dict:
+    :param refpkg_dict: A dictionary of ReferencePackage instances indexed by their prefix values
     :return:
     """
     jplace_files = glob.glob(jplace_dir + '*.jplace')
     jplace_collection = organize_jplace_files(jplace_files)
-    for denominator, jplace_files in jplace_collection.items():
+    for refpkg_name, jplace_files in jplace_collection.items():
         try:
-            marker = marker_build_dict[denominator].cog
+            refpkg = refpkg_dict[refpkg_name]
         except KeyError:
             logging.warning("Intermediate files found from a previous run will be skipped:\n\t" +
                             "\n\t".join(jplace_files) + "\n")
@@ -233,7 +218,7 @@ def sub_indices_for_seq_names_jplace(jplace_dir, numeric_contig_index, marker_bu
         for jplace_path in jplace_files:
             jplace_data = jplace_parser(jplace_path)
             for pquery in jplace_data.placements:
-                pquery["n"] = numeric_contig_index[marker][int(pquery["n"][0])]
+                pquery["n"] = numeric_contig_index[refpkg.prefix][int(pquery["n"][0])]
             write_jplace(jplace_data, jplace_dir + os.sep + "tmp.jplace")
             os.rename(jplace_dir + os.sep + "tmp.jplace", jplace_path)
     return
@@ -244,7 +229,7 @@ def add_bipartitions(itol_datum, bipartition_file):
     Adds bootstrap values read from a NEWICK tree-file where they are indicated by values is square-brackets
     and inserts them into a JPlace-formatted NEWICK tree (Internal nodes in curly braces are required)
 
-    :param itol_datum: An ItolJplace object
+    :param itol_datum: An JPlace object
     :param bipartition_file: Path to file containing the bootstrapped tree
     :return: Updated ItolJPlace object
     """
