@@ -263,7 +263,7 @@ def executable_dependency_versions(exe_dict: dict) -> str:
 
     simple_v = ["prodigal", "raxmlHPC", "epa-ng"]
     version_param = ["trimal", "mafft", "raxml-ng"]
-    no_params = ["usearch", "papara"]
+    no_params = ["vsearch", "papara"]
     help_param = ["hmmbuild", "hmmalign", "hmmsearch", "OD-seq"]
     version_re = re.compile(r"[Vv]\d+.\d|version \d+.\d|\d\.\d\.\d|HMMER")
 
@@ -374,7 +374,9 @@ def median(num_list: list):
     n = len(num_list)
     if n < 1:
         return None
-    if n % 2 == 1:
+    elif n == 1:
+        return num_list[0]
+    elif n % 2 == 1:
         return sorted(num_list)[n//2]
     else:
         return sum(sorted(num_list)[n//2-1:n//2+1])/2.0
